@@ -1,6 +1,6 @@
 #include <stdio.h>
 
-static char version[] = "0.2.1 beta";
+static char version[] = "0.2.2 beta";
 
 // 関数プロトタイプ
 void help();
@@ -27,8 +27,11 @@ void help()
 	puts("            一致しなかった場合はdestを削除する。");
 	puts("            (例 : snowcp -5 1 source dest)");
 	puts("");
+	puts(" -0         コンペアを行わない。");
+	puts("            (-1、-5、-cオプションを無効にする。)");
+	puts("");
 	puts(" -b NUMBER  バッファの量を指定する（MB単位）。");
-	puts("            (例 : snowcp -b 64 source dest)");
+	puts("            (例 : snowcp -b 128 source dest)");
 	puts("");
 	puts(" -c MODE    memcmpで比較する。");
 	puts("            MODEが1の場合はコピー直後に、");
@@ -50,5 +53,5 @@ void help()
 	puts("");
 	puts(" -v         コピー中のファイル名を表示する。");
 	puts("");
-	puts("注: -1、-5、-cは同時に指定できない。-i、-nは同時に指定できない。");
+	puts("注 : オプションは後に入力した方が優先される。例えば snowcp -in とした場合、-nオプションが有効になる。");
 }
