@@ -1,12 +1,16 @@
 /*
 gcc -Wall -O -lpthread `pkg-config --cflags --libs glib-2.0` -std=c99 *.c
+↑これでコンパイル可能。
+
+glibを使用しているので、
+sudo apt-get install libgtk2.0-dev
+が必要。
 
 今後の予定
 ・移動モードの実装
 ・コピーログの保存
 
-インデントはタブ文字で行っています。
-タブの幅は半角スペース4文字です。
+インデントはタブ文字。タブの幅は半角スペース4文字。
 */
 
 #define _XOPEN_SOURCE 600
@@ -56,10 +60,10 @@ int compare_mode = 0; // 1か2
 int current_fd = 0;
 
 // 関数プロトタイプ
-static inline __attribute__((always_inline)) void buffer_size_set(const int tmp);
-void handler(int sig);
 static inline __attribute__((always_inline)) void get_today(void);
 static inline __attribute__((always_inline)) void get_settings_dir(void);
+static inline __attribute__((always_inline)) void buffer_size_set(const int tmp);
+void handler(int sig);
 
 /*******************************************************************************
 
@@ -106,7 +110,7 @@ int main(int argc, char *argv[])
 		option_get();
 
 	// オプション解析
-	while((result = getopt(argc, argv, "1:5:b:c:dimnov")) != -1)
+	while((result = getopt(argc, argv, "1:5:0b:c:dimnov")) != -1)
 	{
 		switch(result)
 		{
@@ -147,6 +151,12 @@ int main(int argc, char *argv[])
 				exit(-1);
 			}
 			break;
+		// コンペアを行わない
+		case '0':
+			option = EXIST;
+			C = NOT;
+			compare_mode = 0;
+			break;
 		// バッファサイズを指定
 		case 'b':
 			option = EXIST;
@@ -403,13 +413,21 @@ void get_settings_dir()
 	if(!homedir)
 		homedir = g_get_home_dir();
 
+	// ~/.config
 	config_dir = g_build_path(G_DIR_SEPARATOR_S, homedir, ".config", NULL);
+	// ~/.config/snowcp
 	settings_dir = g_build_path(G_DIR_SEPARATOR_S, config_dir, "snowcp", NULL);
+	// ~/.config/snowcp/snowcp.conf
 	config_file = g_build_path(G_DIR_SEPARATOR_S, settings_dir, "snowcp.conf", NULL);
+	// ~/.config/snowcp/log
 	log_dir = g_build_path(G_DIR_SEPARATOR_S, settings_dir, "log", NULL);
+	// ~/.config/snowcp/log/compare_error
 	compare_error_dir = g_build_path(G_DIR_SEPARATOR_S, log_dir, "compare_error", NULL);
+	// ~/.config/snowcp/log/compare_success
 	compare_success_dir = g_build_path(G_DIR_SEPARATOR_S, log_dir, "compare_success", NULL);
+	// ~/.config/snowcp/log/copy_error
 	copy_error_dir = g_build_path(G_DIR_SEPARATOR_S, log_dir, "copy_error", NULL);
+	// ~/.config/snowcp/log/copy_success
 	copy_success_dir = g_build_path(G_DIR_SEPARATOR_S, log_dir, "copy_success", NULL);
 }
 
@@ -435,5 +453,6 @@ void handler(int sig)
 	printf("signal number = %d\n", sig);
 	if(write_now != NULL)
 		unlink(write_now);
+	printf("書き込み中の %s を削除しました\n", write_now);
 	exit(-1);
 }
